//+------------------------------------------------------------------+
//|                                              Meta_M1_Problem.mq4 |
//|                                           copyright(c) Project V |
//+------------------------------------------------------------------+
#property copyright "(c)Project V"
#property link      "http://projectv-japan.sblo.jp/"

extern string  _Entry_Setting    = "----------Entry Setting";
extern double  Lots              = 0.01;
extern int     TakeProfit        = 2;
extern int     StopLoss          = 10;
extern int     SignalPips        = 4;

//memo
bool   system_error = false;
int    buyticket    = -1;
int    sellticket   = -1;
double buyprice     = 0;
double sellprice    = 0;

//+------------------------------------------------------------------+
//| expert initialization function                                   |
//+------------------------------------------------------------------+
int init()
{
   int spread = 2;
   //digits
   if(Digits == 3 || Digits == 5)
   {
      TakeProfit *= 10;
      StopLoss   *= 10;
      SignalPips *= 10;
      spread     *= 10;
   }
   
   //chart error
   string error_comment;
   if(!IsTesting())
   {
      error_comment = "Testing only.";
      Comment("\n", error_comment);
      Alert(error_comment);
      system_error = true;
   }
   if(MarketInfo(Symbol(),MODE_SPREAD)>spread)
   {
      error_comment = "Spread is too wide.";
      Comment("\n", error_comment);
      Alert(error_comment);
      system_error = true;
   }
   return(0);
}

//+------------------------------------------------------------------+
//| expert start function                                            |
//+------------------------------------------------------------------+
int start()
{
   //error
   if(system_error) return(0);
   
   if(buyticket >= 0)
   {
      if(Bid >= buyprice + TakeProfit * Point || Bid <= buyprice - StopLoss * Point)
      {
         OrderClose(buyticket, Lots, Bid, 0);
         buyticket = -1;
      }
   }
   if(sellticket >= 0)
   {
      if(Ask <= sellprice - TakeProfit * Point || Ask >= sellprice + StopLoss * Point)
      {
         OrderClose(sellticket, Lots, Ask, 0);
         sellticket = -1;
      }
   }
   
   //sign
   int sign;
   double m1_open = iOpen(NULL, 1, 0);
   if(m1_open > 0)
   {
      if(Bid <= m1_open - SignalPips * Point) sign = 1;
      if(Bid >= m1_open + SignalPips * Point) sign = -1;
   }
   
   //order
   if(sign == 1)
   {
      if(buyticket<0)
      {
         buyticket = OrderSend(Symbol(), OP_BUY, Lots, Ask, 0, 0, 0);
         buyprice = Ask;
         return(0);
      }
   }
   if(sign == -1)
   {
      if(sellticket<0)
      {
         sellticket = OrderSend(Symbol(), OP_SELL, Lots, Bid, 0, 0, 0);
         sellprice = Bid;
         return(0);
      }
   }
   return(0);
}


